distribution

module
v0.0.0-...-397deb4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 29, 2025 License: MIT

README

your-lib

Библиотека на Go для предсказуемого дробления произвольных чисел на заранее заданные доли.

Go Reference CI Go Report Card


Установка

go get github.com/barugoo/distribution@latest

Быстрый старт

package main

import (
	"fmt"
	"github.com/barugoo/distribution"
)

func main() {
	c := yourlib.New(yourlib.WithPrefix("demo: "))
	out := c.Do("hello")
	fmt.Println(out)
}

Почему your-lib?

  • Простое, предсказуемое API
  • Минимум зависимостей
  • Семантическое версионирование и стабильность API после v1

Документация


Безопасность

См. SECURITY.md.


Вклад

См. CONTRIBUTING.md. Будем рады любому участию! 🙌

Directories

Path Synopsis
Package core provides the core functionality for the distribution library
Package core provides the core functionality for the distribution library
Example of how to use the distribution core package
Example of how to use the distribution core package
products
Package products provides an example of how to use the distribution core package
Package products provides an example of how to use the distribution core package

Jump to